@@ -20,8 +20,6 @@
 # All data is binary. This is important for Python3
 # All parameter names are converted to and processed as str/unicode
 
-from __future__ import print_function
-
 import sys
 import os
 import tempfile
@@ -30,7 +28,6 @@ import getopt
 import rclconfig
 import cmdtalk
 
-PY3 = (sys.version > '3')
 _g_mswindows = (sys.platform == "win32")
 _g_execdir = os.path.dirname(sys.argv[0])
 
@@ -62,12 +59,11 @@ def makebytes(data):
 # Possibly decode binary file name for use as subprocess argument,
 # depending on platform.
 def subprocfile(fn):
-    # On Windows PY3 the list2cmdline() method in subprocess assumes that
-    # all args are str, and we receive file names as UTF-8. So we need
-    # to convert.
-    # On Unix all list elements get converted to bytes in the C
-    # _posixsubprocess module, nothing to do.
-    if PY3 and _g_mswindows and type(fn) != type(''):
+    # On Windows Python 3 the list2cmdline() method in subprocess assumes that all args are str, and
+    # we receive file names as UTF-8. So we need to convert.
+    # On Unix all list elements get converted to bytes in the C _posixsubprocess module, nothing to
+    # do.
+    if _g_mswindows and type(fn) != type(''):
         return fn.decode('UTF-8')
     else:
         return fn
@@ -265,19 +261,30 @@ def execPythonScript(icmd):
     
 # Temp dir helper
 class SafeTmpDir:
-    def __init__(self, em):
+    def __init__(self, tag, em=None):
+        self.tag = tag
         self.em = em
-        self.toptmp = ""
-        self.tmpdir = ""
+        self.toptmp = None
+        self.tmpdir = None
 
     def __del__(self):
-        try:
-            if self.toptmp:
-                shutil.rmtree(self.tmpdir, True)
+        if self.toptmp:
+            try:
+                if self.tmpdir:
+                    shutil.rmtree(self.tmpdir, True)
                 os.rmdir(self.toptmp)
-        except Exception as err:
-            self.em.rclog("delete dir failed for " + self.toptmp)
+            except Exception as err:
+                if self.em:
+                    self.em.rclog("delete dir failed for " + self.toptmp)
 
+    def vacuumdir(self):
+        if self.tmpdir:
+            for fn in os.listdir(self.tmpdir):
+                path = os.path.join(self.tmpdir, fn)
+                if os.path.isfile(path):
+                    os.unlink(path)
+        return True
+    
     def getpath(self):
         if not self.tmpdir:
             envrcltmp = os.getenv('RECOLL_TMPDIR')
@@ -286,7 +293,7 @@ class SafeTmpDir:
             else:
                 self.toptmp = tempfile.mkdtemp(prefix='rcltmp')
 
-            self.tmpdir = os.path.join(self.toptmp, 'rclsofftmp')
+            self.tmpdir = os.path.join(self.toptmp, self.tag)
             os.makedirs(self.tmpdir)
 
         return self.tmpdir
@@ -305,8 +312,7 @@ def main(proto, extract):
     # Not running the main loop: either acting as single filter (when called
     # from other filter for example), or debugging
     def usage():
-        print("Usage: rclexecm.py [-d] [-s] [-i ipath] <filename>",
-              file=sys.stderr)
+        print("Usage: rclexecm.py [-d] [-f] [-h] [-i ipath] [-s] <filename>", file=sys.stderr)
         print("       rclexecm.py -w <prog>", file=sys.stderr)
         sys.exit(1)
         
@@ -361,7 +367,7 @@ def main(proto, extract):
 
     params = {'filename' : makebytes(path)}
 
-    # Some filters (e.g. rclaudio) need/get a MIME type from the indexer.
+    # Some filters (e.g. rclaudio.py) need/get a MIME type from the indexer.
     # We make a half-assed attempt to emulate:
     mimetype = _g_config.mimeType(path)
     if not mimetype and not _g_mswindows:
@@ -373,10 +379,7 @@ def main(proto, extract):
         print("Open error", file=sys.stderr)
         sys.exit(1)
 
-    if PY3:
-        ioout = sys.stdout.buffer
-    else:
-        ioout = sys.stdout
+    ioout = sys.stdout.buffer
     if ipath != b"" or actAsSingle:
         params['ipath'] = ipath
         ok, data, ipath, eof = extract.getipath(params)
